.. PyDrive2 documentation master file, created by
   sphinx-quickstart on Sun Jun 12 23:01:40 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to PyDrive2's documentation!
====================================

PyDrive2 is a wrapper library of `google-api-python-client`_ that simplifies many common Google Drive API tasks.

Project Info
============

- Package: `https://pypi.python.org/pypi/PyDrive2 <https://pypi.python.org/pypi/PyDrive2>`_
- Documentation: `https://docs.iterative.ai/PyDrive2 <https://docs.iterative.ai/PyDrive2>`_
- Source: `https://github.com/iterative/PyDrive2 <https://github.com/iterative/PyDrive2>`_
- Changelog: `https://github.com/iterative/PyDrive2/releases <https://github.com/iterative/PyDrive2/releases>`_

How to install
==============

You can install PyDrive2 with regular ``pip`` command.

::

    $ pip install PyDrive2

To install the current development version from GitHub, use:

::

    $ pip install git+https://github.com/iterative/PyDrive2.git#egg=PyDrive2


.. _`google-api-python-client`: https://github.com/google/google-api-python-client

Table of Contents
=================

.. toctree::
   :maxdepth: 2

   quickstart
   oauth
   filemanagement
   filelist
   fsspec
   pydrive2
   genindex
